@@ -10,17 +10,19 @@ use crate::{
     client::{ClientHandle, ClientManager},
     command::CommandManager,
     config::Config,
-    editor_utils::{ReadLine, RegisterCollection, RegisterKey, StatusBar, StringPool},
+    editor_utils::{
+        KeyMapCollection, MatchResult, ReadLine, RegisterCollection, RegisterKey, StatusBar,
+        StringPool,
+    },
     events::{
         ClientEvent, EditorEvent, EditorEventIter, EditorEventQueue, KeyParseAllError, KeyParser,
         ServerEvent, TargetClient,
     },
-    keymap::{KeyMapCollection, MatchResult},
     mode::{Mode, ModeKind},
     pattern::Pattern,
     picker::Picker,
     platform::{Key, Platform, PlatformRequest},
-    plugin::PluginCollection,
+    plugin::{PluginCollection, PluginHandle},
     syntax::{HighlightResult, SyntaxCollection},
     theme::Theme,
     ui,
@@ -28,7 +30,7 @@ use crate::{
 };
 
 #[derive(Clone, Copy)]
-pub enum EditorControlFlow {
+pub enum EditorFlow {
     Continue,
     Suspend,
     Quit,
@@ -316,11 +318,16 @@ impl Editor {
         Mode::change_to(self, next);
     }
 
+    pub fn enter_plugin_mode(&mut self, plugin_handle: PluginHandle) {
+        Mode::change_to(self, ModeKind::Plugin);
+        self.mode.plugin_handle = Some(plugin_handle);
+    }
+
     pub fn execute_keys(
         ctx: &mut EditorContext,
         client_handle: ClientHandle,
         mut keys: KeysIterator,
-    ) -> EditorControlFlow {
+    ) -> EditorFlow {
         let start_index = keys.index;
 
         match ctx.editor.keymaps.matches(
@@ -328,7 +335,7 @@ impl Editor {
             &ctx.editor.buffered_keys.0[start_index..],
         ) {
             MatchResult::None => (),
-            MatchResult::Prefix => return EditorControlFlow::Continue,
+            MatchResult::Prefix => return EditorFlow::Continue,
             MatchResult::ReplaceWith(replaced_keys) => {
                 ctx.editor.buffered_keys.0.truncate(start_index);
                 ctx.editor.buffered_keys.0.extend_from_slice(replaced_keys);
@@ -341,9 +348,9 @@ impl Editor {
             }
             let from_index = ctx.editor.recording_macro.map(|_| keys.index);
 
-            match Mode::on_client_keys(ctx, client_handle, &mut keys) {
-                None => return EditorControlFlow::Continue,
-                Some(EditorControlFlow::Continue) => (),
+            match Mode::on_keys(ctx, client_handle, &mut keys) {
+                None => return EditorFlow::Continue,
+                Some(EditorFlow::Continue) => (),
                 Some(flow) => {
                     ctx.editor.enter_mode(ModeKind::default());
                     ctx.editor.buffered_keys.0.truncate(start_index);
@@ -364,21 +371,21 @@ impl Editor {
         }
 
         ctx.editor.buffered_keys.0.truncate(start_index);
-        EditorControlFlow::Continue
+        EditorFlow::Continue
     }
 
     pub(crate) fn on_client_event(
         ctx: &mut EditorContext,
         client_handle: ClientHandle,
         event: ClientEvent,
-    ) -> EditorControlFlow {
+    ) -> EditorFlow {
         match event {
             ClientEvent::Key(target, key) => {
                 let client_handle = match target {
                     TargetClient::Sender => client_handle,
                     TargetClient::Focused => match ctx.clients.focused_client() {
                         Some(handle) => handle,
-                        None => return EditorControlFlow::Continue,
+                        None => return EditorFlow::Continue,
                     },
                 };
 
@@ -397,14 +404,14 @@ impl Editor {
             ClientEvent::Resize(width, height) => {
                 let client = ctx.clients.get_mut(client_handle);
                 client.viewport_size = (width, height);
-                EditorControlFlow::Continue
+                EditorFlow::Continue
             }
             ClientEvent::Command(target, command) => {
                 let client_handle = match target {
                     TargetClient::Sender => client_handle,
                     TargetClient::Focused => match ctx.clients.focused_client() {
                         Some(handle) => handle,
-                        None => return EditorControlFlow::Continue,
+                        None => return EditorFlow::Continue,
                     },
                 };
 
@@ -419,7 +426,7 @@ impl Editor {
                     TargetClient::Sender => client_handle,
                     TargetClient::Focused => match ctx.clients.focused_client() {
                         Some(handle) => handle,
-                        None => return EditorControlFlow::Continue,
+                        None => return EditorFlow::Continue,
                     },
                 };
 
@@ -427,7 +434,7 @@ impl Editor {
                     .get_mut(client_handle)
                     .on_stdin_input(&mut ctx.editor, bytes);
                 ctx.trigger_event_handlers();
-                EditorControlFlow::Continue
+                EditorFlow::Continue
             }
         }
     }
