@@ -6,24 +6,18 @@ use crate::{
     buffer_view::CursorMovementKind,
     client::ClientHandle,
     cursor::{Cursor, CursorCollection},
-    editor::{Editor, EditorContext, EditorControlFlow, KeysIterator},
+    editor::{Editor, EditorContext, EditorFlow, KeysIterator},
     editor_utils::{parse_process_command, MessageKind, ReadLinePoll, ResidualStrBytes},
     events::EditorEventQueue,
     mode::{ModeKind, ModeState},
     pattern::Pattern,
     platform::{PlatformRequest, PooledBuf, ProcessTag},
-    plugin::PluginHandle,
     word_database::WordDatabase,
 };
 
 pub struct State {
-    pub on_client_keys: fn(
-        &mut EditorContext,
-        ClientHandle,
-        &mut KeysIterator,
-        ReadLinePoll,
-    ) -> Option<EditorControlFlow>,
-    pub plugin_handle: Option<PluginHandle>,
+    pub on_client_keys:
+        fn(&mut EditorContext, ClientHandle, &mut KeysIterator, ReadLinePoll) -> Option<EditorFlow>,
     previous_position: BufferPosition,
     find_pattern_command: String,
     find_pattern_buffer_handle: Option<BufferHandle>,
@@ -75,8 +69,7 @@ impl State {
 impl Default for State {
     fn default() -> Self {
         Self {
-            on_client_keys: |_, _, _, _| Some(EditorControlFlow::Continue),
-            plugin_handle: None,
+            on_client_keys: |_, _, _, _| Some(EditorFlow::Continue),
             previous_position: BufferPosition::zero(),
             find_pattern_command: String::new(),
             find_pattern_buffer_handle: None,
@@ -91,17 +84,16 @@ impl ModeState for State {
     }
 
     fn on_exit(editor: &mut Editor) {
-        let state = &mut editor.mode.read_line_state;
-        state.plugin_handle = None;
-        state.find_pattern_command.clear();
+        editor.mode.plugin_handle = None;
+        editor.mode.read_line_state.find_pattern_command.clear();
         editor.read_line.input_mut().clear();
     }
 
-    fn on_client_keys(
+    fn on_keys(
         ctx: &mut EditorContext,
         client_handle: ClientHandle,
         keys: &mut KeysIterator,
-    ) -> Option<EditorControlFlow> {
+    ) -> Option<EditorFlow> {
         let poll = ctx.editor.read_line.poll(
             &mut ctx.platform,
             &mut ctx.editor.string_pool,
@@ -124,7 +116,7 @@ pub mod search {
             client_handle: ClientHandle,
             _: &mut KeysIterator,
             poll: ReadLinePoll,
-        ) -> Option<EditorControlFlow> {
+        ) -> Option<EditorFlow> {
             match poll {
                 ReadLinePoll::Pending => {
                     update_search(ctx, client_handle);
@@ -161,7 +153,7 @@ pub mod search {
                 }
             }
 
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         }
 
         save_current_position(ctx, client_handle);
@@ -249,7 +241,7 @@ pub mod filter_cursors {
             on_submitted(ctx, client_handle, poll, |ctx, client_handle| {
                 on_event_impl(ctx, client_handle, true);
             });
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         };
         ctx.editor.enter_mode(ModeKind::ReadLine);
     }
@@ -260,7 +252,7 @@ pub mod filter_cursors {
             on_submitted(ctx, client_handle, poll, |ctx, client_handle| {
                 on_event_impl(ctx, client_handle, false);
             });
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         };
         ctx.editor.enter_mode(ModeKind::ReadLine);
     }
@@ -394,7 +386,7 @@ pub mod split_cursors {
             on_submitted(ctx, client_handle, poll, |ctx, client_handle| {
                 on_event_impl(ctx, client_handle, add_matches);
             });
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         };
         ctx.editor.enter_mode(ModeKind::ReadLine);
     }
@@ -451,7 +443,7 @@ pub mod split_cursors {
             on_submitted(ctx, client_handle, poll, |ctx, client_handle| {
                 on_event_impl(ctx, client_handle, add_matches);
             });
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         };
         ctx.editor.enter_mode(ModeKind::ReadLine);
     }
@@ -572,12 +564,12 @@ pub mod goto {
             client_handle: ClientHandle,
             _: &mut KeysIterator,
             poll: ReadLinePoll,
-        ) -> Option<EditorControlFlow> {
+        ) -> Option<EditorFlow> {
             match poll {
                 ReadLinePoll::Pending => {
                     let line_number: usize = match ctx.editor.read_line.input().parse() {
                         Ok(number) => number,
-                        Err(_) => return Some(EditorControlFlow::Continue),
+                        Err(_) => return Some(EditorFlow::Continue),
                     };
                     let line_index = line_number.saturating_sub(1);
 
@@ -606,7 +598,7 @@ pub mod goto {
                     ctx.editor.enter_mode(ModeKind::default());
                 }
             }
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         }
 
         save_current_position(ctx, client_handle);
@@ -625,17 +617,17 @@ pub mod process {
             client_handle: ClientHandle,
             _: &mut KeysIterator,
             poll: ReadLinePoll,
-        ) -> Option<EditorControlFlow> {
+        ) -> Option<EditorFlow> {
             match poll {
-                ReadLinePoll::Pending => Some(EditorControlFlow::Continue),
+                ReadLinePoll::Pending => Some(EditorFlow::Continue),
                 ReadLinePoll::Submitted => {
                     spawn_process(ctx, client_handle, true);
                     ctx.editor.enter_mode(ModeKind::default());
-                    Some(EditorControlFlow::Continue)
+                    Some(EditorFlow::Continue)
                 }
                 ReadLinePoll::Canceled => {
                     ctx.editor.enter_mode(ModeKind::default());
-                    Some(EditorControlFlow::Continue)
+                    Some(EditorFlow::Continue)
                 }
             }
         }
@@ -651,17 +643,17 @@ pub mod process {
             client_handle: ClientHandle,
             _: &mut KeysIterator,
             poll: ReadLinePoll,
-        ) -> Option<EditorControlFlow> {
+        ) -> Option<EditorFlow> {
             match poll {
-                ReadLinePoll::Pending => Some(EditorControlFlow::Continue),
+                ReadLinePoll::Pending => Some(EditorFlow::Continue),
                 ReadLinePoll::Submitted => {
                     spawn_process(ctx, client_handle, false);
                     ctx.editor.enter_mode(ModeKind::default());
-                    Some(EditorControlFlow::Continue)
+                    Some(EditorFlow::Continue)
                 }
                 ReadLinePoll::Canceled => {
                     ctx.editor.enter_mode(ModeKind::default());
-                    Some(EditorControlFlow::Continue)
+                    Some(EditorFlow::Continue)
                 }
             }
         }
@@ -677,9 +669,9 @@ pub mod process {
             _: ClientHandle,
             _: &mut KeysIterator,
             poll: ReadLinePoll,
-        ) -> Option<EditorControlFlow> {
+        ) -> Option<EditorFlow> {
             match poll {
-                ReadLinePoll::Pending => Some(EditorControlFlow::Continue),
+                ReadLinePoll::Pending => Some(EditorFlow::Continue),
                 ReadLinePoll::Submitted => {
                     let command = ctx.editor.read_line.input();
                     if let Some(mut command) = parse_process_command(command) {
@@ -697,11 +689,11 @@ pub mod process {
                     }
 
                     ctx.editor.enter_mode(ModeKind::default());
-                    Some(EditorControlFlow::Continue)
+                    Some(EditorFlow::Continue)
                 }
                 ReadLinePoll::Canceled => {
                     ctx.editor.enter_mode(ModeKind::default());
-                    Some(EditorControlFlow::Continue)
+                    Some(EditorFlow::Continue)
                 }
             }
         }
@@ -780,13 +772,13 @@ pub mod find_pattern {
             client_handle: ClientHandle,
             _: &mut KeysIterator,
             poll: ReadLinePoll,
-        ) -> Option<EditorControlFlow> {
+        ) -> Option<EditorFlow> {
             match poll {
-                ReadLinePoll::Pending => return Some(EditorControlFlow::Continue),
+                ReadLinePoll::Pending => return Some(EditorFlow::Continue),
                 ReadLinePoll::Submitted => (),
                 ReadLinePoll::Canceled => {
                     ctx.editor.enter_mode(ModeKind::default());
-                    return Some(EditorControlFlow::Continue);
+                    return Some(EditorFlow::Continue);
                 }
             }
 
@@ -808,7 +800,7 @@ pub mod find_pattern {
                         .status_bar
                         .write(MessageKind::Error)
                         .fmt(format_args!("{}", error));
-                    return Some(EditorControlFlow::Continue);
+                    return Some(EditorFlow::Continue);
                 }
             };
 
@@ -846,7 +838,7 @@ pub mod find_pattern {
                             "invalid find pattern command '{}'",
                             &state.find_pattern_command
                         ));
-                    return Some(EditorControlFlow::Continue);
+                    return Some(EditorFlow::Continue);
                 }
             };
 
@@ -876,7 +868,7 @@ pub mod find_pattern {
             }
 
             ctx.editor.enter_mode(ModeKind::default());
-            Some(EditorControlFlow::Continue)
+            Some(EditorFlow::Continue)
         }
 
         ctx.editor.read_line.set_prompt(prompt);
